import{V as j,e as D,W as E,G as H,K as I,p as m,c as _,n as h,r as b,t as g,a as k,f as G,R as J,F as R}from"./CioMtalE.js";import"./CWj6FrbW.js";import{t as x,a as f,c as K}from"./8I6xAQmg.js";import{s as d}from"./CxwmnHuf.js";import{a as B,g as L}from"./CnvS_7Kp.js";import{p as u,b as P,r as y}from"./i2x3WpvN.js";import{a as F}from"./gsB6E_W3.js";import{i as T}from"./CTeLhLzh.js";import{C as M}from"./Dwy0Nt4n.js";function le(i,e,t){j(()=>{var r=D(()=>e(i,t==null?void 0:t())||{});if(t&&(r!=null&&r.update)){var a=!1,s={};E(()=>{var l=t();H(l),a&&I(s,l)&&(s=l,r.update(l))}),a=!0}if(r!=null&&r.destroy)return()=>r.destroy()})}var N=x("<nav><!></nav>");function ne(i,e){m(e,!0);let t=u(e,"ref",15),r=y(e,["$$slots","$$events","$$legacy","ref","class","children"]);var a=N();let s;var l=_(a);d(l,()=>e.children??h),b(a),P(a,n=>t(n),()=>t()),g(()=>s=B(a,s,{class:e.class,"aria-label":"breadcrumb",...r})),f(i,a),k()}var O=x("<li><!></li>");function ie(i,e){m(e,!0);let t=u(e,"ref",15,null),r=y(e,["$$slots","$$events","$$legacy","ref","class","children"]);var a=O();let s;var l=_(a);d(l,()=>e.children??h),b(a),P(a,n=>t(n),()=>t()),g(n=>s=B(a,s,{class:n,...r}),[()=>F("inline-flex items-center gap-1.5",e.class)]),f(i,a),k()}var Q=x("<li><!></li>");function ce(i,e){m(e,!0);let t=u(e,"ref",15,null),r=y(e,["$$slots","$$events","$$legacy","ref","class","children"]);var a=Q();let s;var l=_(a);{var n=c=>{var w=K(),z=G(w);d(z,()=>e.children??h),f(c,w)},q=c=>{M(c,{})};T(l,c=>{e.children?c(n):c(q,!1)})}b(a),P(a,c=>t(c),()=>t()),g(c=>s=B(a,s,{role:"presentation","aria-hidden":"true",class:c,...r}),[()=>F("[&>svg]:size-3.5",e.class)]),f(i,a),k()}var S=x("<a><!></a>");function fe(i,e){m(e,!0);let t=u(e,"ref",15,null),r=u(e,"href",3,void 0),a=y(e,["$$slots","$$events","$$legacy","ref","class","href","child","children"]);const s=J(()=>({class:F("hover:text-foreground transition-colors",e.class),href:r(),...a})),l=L(),[n,q]=l;var c=K(),w=G(c);{var z=v=>{var o=K(),C=G(o);d(C,()=>e.child,()=>({props:R(s)})),f(v,o)},V=v=>{var o=S();let C;var W=_(o);d(W,()=>e.children??h),b(o),P(o,A=>t(A),()=>t()),g(A=>C=B(o,C,{...A}),[()=>q({...R(s)},[{attribute_name:"href",lang_attribute_name:"hreflang"}])]),f(v,o)};T(w,v=>{e.child?v(z):v(V,!1)})}f(i,c),k()}var U=x("<ol><!></ol>");function oe(i,e){m(e,!0);let t=u(e,"ref",15,null),r=y(e,["$$slots","$$events","$$legacy","ref","class","children"]);var a=U();let s;var l=_(a);d(l,()=>e.children??h),b(a),P(a,n=>t(n),()=>t()),g(n=>s=B(a,s,{class:n,...r}),[()=>F("flex flex-wrap items-center gap-1.5 break-words text-sm text-muted-foreground sm:gap-2.5",e.class)]),f(i,a),k()}var X=x("<span><!></span>");function de(i,e){m(e,!0);let t=u(e,"ref",15,null),r=y(e,["$$slots","$$events","$$legacy","ref","class","children"]);var a=X();let s;var l=_(a);d(l,()=>e.children??h),b(a),P(a,n=>t(n),()=>t()),g(n=>s=B(a,s,{role:"link","aria-disabled":"true","aria-current":"page",class:n,...r}),[()=>F("font-normal text-foreground",e.class)]),f(i,a),k()}export{ne as B,le as a,oe as b,ie as c,de as d,fe as e,ce as f};
