import{L as c,M as o,N as E,O as v,T as p,P as x,m as f,o as i,q as M,x as N}from"./CioMtalE.js";function h(r){var t=document.createElement("template");return t.innerHTML=r,t.content}function n(r,t){var e=v;e.nodes_start===null&&(e.nodes_start=r,e.nodes_end=t)}function C(r,t){var e=(t&p)!==0,l=(t&x)!==0,s,m=!r.startsWith("<!>");return()=>{if(f)return n(i,null),i;s===void 0&&(s=h(m?r:"<!>"+r),e||(s=o(s)));var a=l||E?document.importNode(s,!0):s.cloneNode(!0);if(e){var _=o(a),d=a.lastChild;n(_,d)}else n(a,a);return a}}function L(r,t,e="svg"){var l=!r.startsWith("<!>"),s=(t&p)!==0,m=`<${e}>${l?r:"<!>"+r}</${e}>`,a;return()=>{if(f)return n(i,null),i;if(!a){var _=h(m),d=o(_);if(s)for(a=document.createDocumentFragment();o(d);)a.appendChild(o(d));else a=o(d)}var u=a.cloneNode(!0);if(s){var g=o(u),T=u.lastChild;n(g,T)}else n(u,u);return u}}function P(r=""){if(!f){var t=c(r+"");return n(t,t),t}var e=i;return e.nodeType!==3&&(e.before(e=c()),N(e)),n(e,e),e}function b(){if(f)return n(i,null),i;var r=document.createDocumentFragment(),t=document.createComment(""),e=c();return r.append(t,e),n(t,e),r}function A(r,t){if(f){v.nodes_end=i,M();return}r!==null&&r.before(t)}export{A as a,P as b,b as c,n as d,h as e,L as n,C as t};
