var m=s=>{throw TypeError(s)};var l=(s,t,e)=>t.has(s)||m("Cannot "+e);var n=(s,t,e)=>(l(s,t,"read from private field"),e?e.call(s):t.get(s)),i=(s,t,e)=>t.has(s)?m("Cannot add the same private member more than once"):t instanceof WeakSet?t.add(s):t.set(s,e),p=(s,t,e,r)=>(l(s,t,"write to private field"),r?r.call(s,e):t.set(s,e),e);import{o as u}from"./DCQgh7ZV.js";import{c as M,I as $}from"./gsB6E_W3.js";import"./CWj6FrbW.js";import{p as b,f as g,n as v,a as _}from"./CioMtalE.js";import{c as x,a as w}from"./8I6xAQmg.js";import{s as y}from"./CxwmnHuf.js";import{s as B,r as I}from"./i2x3WpvN.js";var a,o;class N{constructor(t,e){i(this,a);i(this,o);p(this,a,t),p(this,o,M(e))}get current(){return n(this,o).call(this),n(this,a).call(this)}}a=new WeakMap,o=new WeakMap;const V=/\(.+\)/;class z extends N{constructor(t,e){let r=V.test(t)?t:`(${t})`;const c=window.matchMedia(r);super(()=>c.matches,h=>u(c,"change",h))}}function A(s,t){b(t,!0);let e=I(t,["$$slots","$$events","$$legacy"]);$(s,B({name:"bot"},()=>e,{iconNode:[["path",{d:"M12 8V4H8"}],["rect",{width:"16",height:"12",x:"4",y:"8",rx:"2"}],["path",{d:"M2 14h2"}],["path",{d:"M20 14h2"}],["path",{d:"M15 13v2"}],["path",{d:"M9 13v2"}]],children:(c,h)=>{var d=x(),f=g(d);y(f,()=>t.children??v),w(c,d)},$$slots:{default:!0}})),_()}export{A as B,z as M};
