import"../chunks/CWj6FrbW.js";import{i as B}from"../chunks/B7cR8DJ5.js";import{p as D,a as L,s as r,c as a,r as e,t as A,Q as C,F as l,f as O}from"../chunks/CioMtalE.js";import{s as w}from"../chunks/DCQgh7ZV.js";import{i as P}from"../chunks/CTeLhLzh.js";import{g as V,e as S,i as T,s as F}from"../chunks/CnvS_7Kp.js";import{t as c,a as p}from"../chunks/8I6xAQmg.js";const ee=Object.freeze(Object.defineProperty({__proto__:null},Symbol.toStringTag,{value:"Module"}));var q=c('<div class="card svelte-edweb8"><a target="_blank" rel="noopener" class="svelte-edweb8"><span> </span> <span> </span></a></div>'),K=c('<span class="sep svelte-edweb8">|</span>'),Q=c('<a target="_blank" rel="noopener" class="svelte-edweb8"> </a> <!>',1),U=c(`<main class="svelte-edweb8"><div class="hero-grid svelte-edweb8"><svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="svelte-edweb8"><path d="M12 8V4H8"></path><rect width="16" height="12" x="4" y="8" rx="2"></rect><path d="M2 14h2"></path><path d="M20 14h2"></path><path d="M15 13v2"></path><path d="M9 13v2"></path></svg> <h1 class="hero-title svelte-edweb8">Xaibo</h1> <div class="hero-subtitle svelte-edweb8">The Modular AI Agent Framework</div></div> <div class="tagline svelte-edweb8">Ready to build robust, production-ready AI agents that are easy to test
    and maintain and ship with clean, protocol-based design?</div> <section class="svelte-edweb8"><h2 class="svelte-edweb8">Documentation</h2> <div class="docs-grid svelte-edweb8"></div></section> <section class="community-section svelte-edweb8"><h2 class="svelte-edweb8">Community</h2> <div class="community svelte-edweb8"></div></section></main>`);function te(G,H){D(H,!1);const I=[{emoji:"🚀",title:"Getting Started Tutorial",href:"https://xaibo.ai/tutorial/"},{emoji:"📖",title:"How-to Guides",href:"https://xaibo.ai/how-to/"},{emoji:"🧠",title:"Core Concepts",href:"https://xaibo.ai/explanation/"},{emoji:"📚",title:"API Reference",href:"https://xaibo.ai/reference/"},{emoji:"🛠️",title:"Building Tools",href:"https://xaibo.ai/tutorial/building-tools/"},{emoji:"⚙️",title:"Architecture Guide",href:"https://xaibo.ai/explanation/architecture/protocols/"}],x=[{emoji:"💻",title:"GitHub Repository",href:"https://github.com/xpressai/xaibo"},{emoji:"💬",title:"Discord Community",href:"https://discord.gg/uASMzSSVKe"},{emoji:"✉️",title:"Contact Us",href:"mailto:hello@xpress.ai"}],R=V(),[j,X]=R;B();var h=U(),v=r(a(h),4),k=r(a(v),2);S(k,5,()=>I,T,(m,s)=>{let u=()=>l(s).emoji,b=()=>l(s).title,_=()=>l(s).href;var n=q(),o=a(n),t=a(o),f=a(t,!0);e(t);var d=r(t,2),g=a(d,!0);e(d),e(o),e(n),A(i=>{F(o,"href",i),w(f,u()),w(g,b())},[()=>j(_(),void 0)],C),p(m,n)}),e(k),e(v);var y=r(v,2),M=r(a(y),2);S(M,5,()=>x,T,(m,s,u)=>{let b=()=>l(s).emoji,_=()=>l(s).title,n=()=>l(s).href;var o=Q(),t=O(o),f=a(t);e(t);var d=r(t,2);{var g=i=>{var z=K();p(i,z)};P(d,i=>{u<x.length-1&&i(g)})}A(i=>{F(t,"href",i),w(f,`${b()??""} ${_()??""}`)},[()=>j(n(),void 0)],C),p(m,o)}),e(M),e(y),e(h),p(G,h),L()}export{te as component,ee as universal};
