import"../chunks/CWj6FrbW.js";import{i as h}from"../chunks/B7cR8DJ5.js";import{p as l,f as v,t as u,a as g,c as e,r as p,s as x}from"../chunks/CioMtalE.js";import{s as o}from"../chunks/DCQgh7ZV.js";import{t as _,a as d}from"../chunks/8I6xAQmg.js";import{p as m}from"../chunks/BUS_Djoz.js";var b=_("<h1> </h1> <p> </p>",1);function z(i,f){l(f,!1),h();var r=b(),t=v(r),n=e(t,!0);p(t);var a=x(t,2),c=e(a,!0);p(a),u(()=>{var s;o(n,m.status),o(c,(s=m.error)==null?void 0:s.message)}),d(i,r),g()}export{z as component};
