import{l as o,u as p,b as t,d as m,e as f,i as v,g as b}from"./CioMtalE.js";function d(e){t===null&&o(),m&&t.l!==null?r(t).m.push(e):p(()=>{const n=f(e);if(typeof n=="function")return n})}function x(e){t===null&&o(),d(()=>()=>f(e))}function y(e,n,{bubbles:a=!1,cancelable:l=!1}={}){return new CustomEvent(e,{detail:n,bubbles:a,cancelable:l})}function h(){const e=t;return e===null&&o(),(n,a,l)=>{var s;const c=(s=e.s.$$events)==null?void 0:s[n];if(c){const i=v(c)?c.slice():[c],u=y(n,a,l);for(const _ of i)_.call(e.x,u);return!u.defaultPrevented}return!0}}function k(e){t===null&&o(),t.l===null&&b(),r(t).b.push(e)}function r(e){var n=e.l;return n.u??(n.u={a:[],b:[],m:[]})}export{x as a,k as b,h as c,d as o};
