main.svelte-edweb8{max-width:640px;margin:2rem auto;padding:0 1rem;font-family:sans-serif}.hero-grid.svelte-edweb8{display:grid;grid-template-columns:auto 1fr;grid-template-rows:auto auto;-moz-column-gap:1rem;column-gap:1rem;align-items:center;margin-bottom:1rem}.hero-grid.svelte-edweb8 svg:where(.svelte-edweb8){grid-row:1 / span 2;width:64px;height:64px}.hero-title.svelte-edweb8{grid-column:2;grid-row:1;font-size:2rem;margin:0}.hero-subtitle.svelte-edweb8{grid-column:2;grid-row:2;font-size:1.25rem;color:#555;margin:0}.tagline.svelte-edweb8{font-size:1rem;margin-bottom:2rem;line-height:1.5}section.svelte-edweb8 h2:where(.svelte-edweb8){font-size:1.5rem;margin-bottom:.75rem;border-bottom:1px solid #ddd;padding-bottom:.25rem}.docs-grid.svelte-edweb8{display:grid;grid-template-columns:repeat(2,1fr);gap:1rem}.card.svelte-edweb8{background:#f9f9f9;padding:1rem;border-radius:8px;box-shadow:0 2px 4px #0000001a}.card.svelte-edweb8 a:where(.svelte-edweb8){color:#1e40af;text-decoration:none;font-weight:500;display:flex;align-items:center;gap:.5rem}.card.svelte-edweb8 a:where(.svelte-edweb8):hover{text-decoration:underline}.community-section.svelte-edweb8 h2:where(.svelte-edweb8){margin-top:2rem}.community.svelte-edweb8{text-align:center;font-size:1rem}.community.svelte-edweb8 a:where(.svelte-edweb8){color:#1e40af;text-decoration:none;margin:0 .25rem}.community.svelte-edweb8 a:where(.svelte-edweb8):hover{text-decoration:underline}.community.svelte-edweb8 span.sep:where(.svelte-edweb8){color:#888}
